@@ -141,8 +141,11 @@ def validate_sample_list(xls_fn,
         else:
             if len(proposal_id)!=6 or len(SAF_id)!=6 or len(plate_id)!=2:
                 raise Exception(f"The bar code (sheet name) does not seem to have the correct format: {bcode}")
-        print(f"proposal: {proposal_id}, SAF: {SAF_id}, plate: {plate_id}")
-        return bcode,df1.set_index("Well").T.to_dict(),mlist
+        bdict = {"proposal_id": proposal_id, 
+                 "SAF_id": SAF_id, 
+                 "plate_id": plate_id} 
+        print(bdict)
+        return bdict,df1.set_index("Well").T.to_dict(),mlist
 
 
 def process_sample_lists(xls_fns, process_all_tabs=False, b_lim=4):
@@ -159,7 +162,7 @@ def process_sample_lists(xls_fns, process_all_tabs=False, b_lim=4):
         else:
             sh_list = [xl.sheet_names[0]]
         for sh_name in sh_list:
-            bcode,wdict,mdict = validate_sample_list(fn, b_lim=b_lim, generate_barcode=False)
+            bdict,wdict,mdict = validate_sample_list(fn, b_lim=b_lim, generate_barcode=False)
             pdict[sh_name] = [wdict, mdict]
     
     # get ot2 layout info
@@ -200,14 +203,14 @@ def process_sample_lists(xls_fns, process_all_tabs=False, b_lim=4):
             # add entry into the sample dictionary
             slist.append([hname, hpos, wdict[wn]["Sample"], wdict[wn]["Buffer"], vt])
 
-    return slist,transfer_list
+    return slist,transfer_list,bdict
 
 def read_OT2_layout(plate_slots, holder_slots):
     """ 
     the arguments should be a comma-separated list of slot positions on the Opentron deck
     e.g. "1,2"  
     """
-    cmd = ["ssh", "-i", "/home/lyang/.ssh/ot2_ssh_key", "-o", "port=9999",
+    cmd = ["ssh", "-i", "/home/xf16id/.ssh/ot2_ssh_key", "-o", "port=9999",
            "root@localhost", "/var/lib/jupyter/notebooks/check_deck_config.py", 
            "-h", holder_slots, "-p", plate_slots]
     
@@ -216,7 +219,7 @@ def read_OT2_layout(plate_slots, holder_slots):
     
     return ldict
 
-def generate_measurement_spreadsheet(fn, slist, holders):
+def generate_measurement_spreadsheet(fn, slist, holders, bdict):
     """ slist is generated by process_sample_lists()
         
         holders is a dictionary of {holder_name: QR code}, derived values retuened 
@@ -238,8 +241,10 @@ def generate_measurement_spreadsheet(fn, slist, holders):
     cdict["QR code"] = holders.values()
     df2 = pd.DataFrame.from_dict(cdict)
 
+    tname = f"{bdict['proposal_id']}-{bdict['SAF_id']}"
+    
     with pd.ExcelWriter(fn) as writer:
-        df1.to_excel(writer, index=False, sheet_name="Holders")
+        df1.to_excel(writer, index=False, sheet_name=tname)
         df2.to_excel(writer, index=False, sheet_name="QR codes")
             
 
@@ -256,7 +261,7 @@ def generate_docs(ot2_layout, xls_fns,
              "tips" : "9,10"}
     """
     print("Processing sample list(s) ...")
-    slist,transfer_list = process_sample_lists(xls_fns, b_lim=b_lim)
+    slist,transfer_list,bdict = process_sample_lists(xls_fns, b_lim=b_lim)
     
     print("Reading bar/QR codes, this might take a while ...")
     ldict = read_OT2_layout(ot2_layout["plates"], ot2_layout["holders"])
@@ -319,7 +324,7 @@ def generate_docs(ot2_layout, xls_fns,
     
     fn = f"{run_name}.xlsx"
     print(f"Writing measurement sequence to {fn}.")
-    generate_measurement_spreadsheet(fn, slist, holders)
+    generate_measurement_spreadsheet(fn, slist, holders, bdict)
     
     print("Done.")
     
@@ -483,7 +488,7 @@ def autofillSpreadsheet(d, fields=['holderName', 'volume']):
             if str(d[ff][idx[i+1]])=='nan':
                 d[ff][idx[i+1]] = d[ff][idx[i]] 
 
-def validateHolderSpreadsheet(fn):
+def validateHolderSpreadsheet(fn, proposal_id, SAF_id):
     # meant to be used by the users to attach to SAF
     # limit to 3 sample holders per spreadsheet
     # validate sample list on the Holders tab and generate QR code for each holder 
@@ -495,6 +500,7 @@ def validateHolderSpreadsheet(fn):
 
     print("Generating QR codes ...")
     wb = openpyxl.load_workbook(fn)
+    wb[wb.sheetnames[0]].title = f"{proposal_id}-{SAF_id}"
     ws1 = wb.create_sheet("QR codes")
     ws1.append(["holderName", "QR code"])
     for i in range(len(hlist)):
